@@ -158,6 +158,15 @@ class TestVersion:
         with pytest.raises(TypeError, match='Field `project.version` must be a string'):
             _ = metadata.version
 
+    def test_static_invalid(self, isolation):
+        metadata = ProjectMetadata(str(isolation), None, {'project': {'version': '0..0'}})
+
+        with pytest.raises(
+            ValueError,
+            match='Invalid version `0..0` from field `project.version`, see https://peps.python.org/pep-0440/',
+        ):
+            _ = metadata.version
+
     def test_static_normalization(self, isolation):
         metadata = ProjectMetadata(str(isolation), None, {'project': {'version': '0.1.0.0-rc.1'}})
 
@@ -221,6 +230,22 @@ class TestVersion:
         assert isinstance(metadata.hatch.version.source, RegexSource)
         assert metadata.hatch.version.cached == metadata.hatch.version.cached == '0.0.1'
 
+    def test_dynamic_source_regex_invalid(self, temp_dir):
+        metadata = ProjectMetadata(
+            str(temp_dir),
+            PluginManager(),
+            {'project': {'dynamic': ['version']}, 'tool': {'hatch': {'version': {'source': 'regex', 'path': 'a/b'}}}},
+        )
+
+        file_path = temp_dir / 'a' / 'b'
+        file_path.ensure_parent_dir_exists()
+        file_path.write_text('__version__ = "0..0"')
+
+        with pytest.raises(
+            ValueError, match='Invalid version `0..0` from source `regex`, see https://peps.python.org/pep-0440/'
+        ):
+            _ = metadata.version
+
     def test_dynamic_error(self, isolation):
         metadata = ProjectMetadata(
             str(isolation),
@@ -1075,6 +1100,19 @@ class TestDependencies:
 
         assert metadata.core.dependencies == ['proj@ git+https://github.com/org/proj.git@v1']
 
+    def test_context_formatting(self, isolation):
+        metadata = ProjectMetadata(
+            str(isolation),
+            None,
+            {
+                'project': {'dependencies': ['proj @ {root:uri}']},
+                'tool': {'hatch': {'metadata': {'allow-direct-references': True}}},
+            },
+        )
+
+        normalized_path = str(isolation).replace('\\', '/')
+        assert metadata.core.dependencies == [f'proj@ file://{normalized_path}']
+
     def test_correct(self, isolation):
         metadata = ProjectMetadata(
             str(isolation),
@@ -1188,6 +1226,19 @@ class TestOptionalDependencies:
         ):
             _ = metadata.core.optional_dependencies
 
+    def test_context_formatting(self, isolation):
+        metadata = ProjectMetadata(
+            str(isolation),
+            None,
+            {
+                'project': {'optional-dependencies': {'foo': ['proj @ {root:uri}']}},
+                'tool': {'hatch': {'metadata': {'allow-direct-references': True}}},
+            },
+        )
+
+        normalized_path = str(isolation).replace('\\', '/')
+        assert metadata.core.optional_dependencies == {'foo': [f'proj@ file://{normalized_path}']}
+
     def test_direct_reference_allowed(self, isolation):
         metadata = ProjectMetadata(
             str(isolation),
